//
//  JFTestAnalyzer.m
//  TestPlugin
//
//  Created by franckej on 19.01.09.
//  Copyright 2009 Jens Francke. All rights reserved.
//

#import "JFTestAnalyzer.h"

#define JFLocalizedStringFromTable(key, tbl, comment) \
[[NSBundle bundleForClass:[self class]] localizedStringForKey:(key) value:@"" table:(tbl)]

@implementation JFTestAnalyzer
@synthesize httpMethod;
@synthesize protocolSize;

- (id) initWithBytes:(const void *)aPayload length:(uint16_t)aPayloadLength previousAnalyzer:(id)prevAnalyzer;
{
    if ((self = [super init])) 
    {  
        if(aPayloadLength<8) {
            [self release];
            return nil;
        }
        else {
            // this is just to demonstrate how to prg. the plugins. dont take this as a serious http-analysis
            [self setProtocolSize:aPayloadLength];
            NSString *testString = [[NSString alloc] initWithBytes:aPayload length:8 encoding:NSASCIIStringEncoding];
            if([testString rangeOfString:@"DELETE"].length >0)[self setHttpMethod:JFLocalizedStringFromTable(@"DELETE", @"LocalizableTestPlugin", @"HTTP Methods")];
            else if([testString rangeOfString:@"GET"].length >0)[self setHttpMethod:JFLocalizedStringFromTable(@"GET", @"LocalizableTestPlugin", @"HTTP Methods")];
            else if([testString rangeOfString:@"HEAD"].length >0)[self setHttpMethod:JFLocalizedStringFromTable(@"HEAD", @"LocalizableTestPlugin", @"HTTP Methods")];
            else if([testString rangeOfString:@"LINK"].length >0)[self setHttpMethod:JFLocalizedStringFromTable(@"LINK", @"LocalizableTestPlugin", @"HTTP Methods")];
            else if([testString rangeOfString:@"OPTIONS"].length >0)[self setHttpMethod:JFLocalizedStringFromTable(@"OPTIONS", @"LocalizableTestPlugin", @"HTTP Methods")];
            else if([testString rangeOfString:@"PATCH"].length >0)[self setHttpMethod:JFLocalizedStringFromTable(@"PATCH", @"LocalizableTestPlugin", @"HTTP Methods")];
            else if([testString rangeOfString:@"POST"].length >0)[self setHttpMethod:JFLocalizedStringFromTable(@"POST", @"LocalizableTestPlugin", @"HTTP Methods")];
            else if([testString rangeOfString:@"PUT"].length >0)[self setHttpMethod:JFLocalizedStringFromTable(@"PUT", @"LocalizableTestPlugin", @"HTTP Methods")];
            else if([testString rangeOfString:@"TRACE"].length >0)[self setHttpMethod:JFLocalizedStringFromTable(@"TRACE", @"LocalizableTestPlugin", @"HTTP Methods")];
            else if([testString rangeOfString:@"UNLINK"].length >0)[self setHttpMethod:JFLocalizedStringFromTable(@"UNLINK", @"LocalizableTestPlugin", @"HTTP Methods")];
            [testString release];
            testString = nil;
        }
    }
    return self;
    
}

- (void) dealloc
{
    [self setHttpMethod:nil];
    [super dealloc];
}
#pragma mark -
#pragma mark Accessors
- (BOOL)hasPayload {
    return YES;
}

- (NSString *) protocolName {
    return nil;
}

- (NSString *) protocolInfo {
    return [self httpMethod];
}

- (NSString *) nextProtocol {
    return nil;
}

- (NSArray *) protocolNodes {
    CPANode *httpNode = [CPANode nodeWithName:JFLocalizedStringFromTable(@"HTTP-Header", @"LocalizableTestPlugin", @"HTTP-Header")];
    [httpNode addChild:[CPANode nodeWithName:JFLocalizedStringFromTable(@"Length", @"LocalizableTestPlugin", @"Length") value:[NSString stringWithFormat:JFLocalizedStringFromTable(@"%u bytes", @"LocalizableTestPlugin", @"Length value"),[self protocolSize]]]];
    // we also need to know the header length alone
    [httpNode setHeaderLength:[self protocolSize]];
    [httpNode setHeaderLocation:0];
    if([self httpMethod])[httpNode addChild:[CPANode nodeWithName:JFLocalizedStringFromTable(@"Method", @"LocalizableTestPlugin", @"HTTP method") value:[self httpMethod]]];
    else [httpNode addChild:[CPANode nodeWithName:JFLocalizedStringFromTable(@"Data packet", @"LocalizableTestPlugin", @"HTTP method")]];
    return [NSArray arrayWithObject:httpNode];
}
@end
