//
//  TestPlugin.m
//  TestPlugin
//
//  Created by franckej on 19.01.09.
//  Copyright 2009 Jens Francke. All rights reserved.
//

#import "JFTestPlugin.h"
#import "JFTestAnalyzer.h"

#define JFLocalizedStringFromTable(key, tbl, comment) \
[[NSBundle bundleForClass:[self class]] localizedStringForKey:(key) value:@"" table:(tbl)]

@implementation JFTestPlugin
- (id) initWithPlugInsController:(CPAPlugInsController*)plugInsController
{
    self = [super initWithWindowNibName:@"Preferences"];
    if (self != nil) {
        NSBundle *pluginBundle = [NSBundle bundleForClass:[self class]];
        if(![plugInsController registerPluginPreferencesInstance:self forPlugin:pluginBundle]){
            [self release];
            return nil;
        }
        if(![plugInsController registerAnalyzerClass:[JFTestAnalyzer class] forPlugin:pluginBundle]){
            [self release];
            return nil;
        }
        if(![plugInsController registerProtocol:@"HTTP" port:[NSNumber numberWithInt:80] sourceProtocol:kCPAProtocolTCP forPlugin:pluginBundle]){
            [self release];
            return nil;
        } 
        
        NSTableColumn * newColumn = [[NSTableColumn alloc] initWithIdentifier:JFLocalizedStringFromTable(@"HTTP Method", @"LocalizableTestPlugin", @"HTTP Column Name")];
        [[newColumn headerCell] setStringValue:JFLocalizedStringFromTable(@"HTTP Method", @"LocalizableTestPlugin", @"HTTP Column Name")];
        [newColumn setMinWidth:100];
        [newColumn setWidth:200];
        [plugInsController registerTableColumn:newColumn keyPath:@"httpMethod" bindingOptions:nil forPlugin:pluginBundle];
        [plugInsController registerPredicateOption:[NSDictionary dictionaryWithObjectsAndKeys:JFLocalizedStringFromTable(@"HTTP Method contains", @"LocalizableTestPlugin", @"HTTP Predicate String"),NSDisplayNameBindingOption,@"httpMethod CONTAINS[c] $value",NSPredicateFormatBindingOption,[NSExpression expressionForKeyPath:@"httpMethod"],CPAFindPredicateLeftExpression,JFLocalizedStringFromTable(@"HTTP Method", @"LocalizableTestPlugin", @"HTTP Find Predicate Displayname"),CPAFindPredicateDisplayName,[NSString class],CPAFindPredicateAttrType,nil] forPlugin:pluginBundle];
        [newColumn release];
        
        if(![[NSUserDefaults standardUserDefaults]objectForKey:@"HTTPAnalyzerUsesColor"])[[NSUserDefaults standardUserDefaults] setBool:NO forKey:@"HTTPAnalyzerUsesColor"];
        if(![[NSUserDefaults standardUserDefaults]objectForKey:@"HTTPAnalyzerProtocolColor"])[[NSUserDefaults standardUserDefaults] setObject:[NSArchiver archivedDataWithRootObject:[NSColor brownColor]] forKey:@"HTTPAnalyzerProtocolColor"];       
        [[NSUserDefaults standardUserDefaults] addObserver:self forKeyPath:@"HTTPAnalyzerUsesColor" options:(NSKeyValueObservingOptionNew) context:NULL];
        [[NSUserDefaults standardUserDefaults] addObserver:self forKeyPath:@"HTTPAnalyzerProtocolColor" options:(NSKeyValueObservingOptionNew) context:NULL];

        
    }
    return self;
}

- (void)dealloc
{
    [[NSUserDefaults standardUserDefaults] removeObserver:self forKeyPath:@"HTTPAnalyzerUsesColor"];
    [[NSUserDefaults standardUserDefaults] removeObserver:self forKeyPath:@"HTTPAnalyzerProtocolColor"];
    [super dealloc];
}

#pragma mark -
#pragma mark PluginInfos
+ (NSString *)pluginVersion
{
    return [[[NSBundle bundleForClass:[self class]] infoDictionary] objectForKey:@"CFBundleVersion"];
}

+ (NSString *)pluginAuthor
{
    return JFLocalizedStringFromTable(@"Jens Francke", @"LocalizableTestPlugin", @"Plugin Author");
}

+ (NSString *)pluginTitle
{
    return JFLocalizedStringFromTable(@"HTTP Analyzer", @"LocalizableTestPlugin", @"Plugin Title");
}

+ (NSString *)pluginDescription
{
    return JFLocalizedStringFromTable(@"HTTP Protocol Test Plugin Analyzer", @"LocalizableTestPlugin", @"Plugin Description");
}

#pragma mark -
#pragma mark Preferences
- (BOOL)usesColor {
    return [[NSUserDefaults standardUserDefaults]boolForKey:@"HTTPAnalyzerUsesColor"];
}

- (NSColor*)protocolColor
{
    NSColor *color= nil;
    NSData  *data =[[NSUserDefaults standardUserDefaults]objectForKey:@"HTTPAnalyzerProtocolColor"];
    if (data != nil) color =(NSColor *)[NSUnarchiver unarchiveObjectWithData:data];
    return color;
}

- (NSWindow*)preferencesSheet
{
    return [self window];
}

- (IBAction)applyPrefsAction:(id)sender
{   
    [[NSUserDefaults standardUserDefaults] synchronize];
    [NSApp endSheet: [self window] returnCode:1];
}
#pragma mark -
#pragma mark Observers
- (void)observeValueForKeyPath:(NSString *)keyPath
                      ofObject:(id)object
                        change:(NSDictionary *)change
                       context:(void *)context
{
    if([keyPath isEqualToString:@"HTTPAnalyzerUsesColor"]||[keyPath isEqualToString:@"HTTPAnalyzerProtocolColor"]) [[NSNotificationCenter defaultCenter] postNotificationName:kReloadPacketsView object:self];
    else {
        [super observeValueForKeyPath:keyPath ofObject:object change:change context:context];
    }
}
@end
